==> flutterbudpay-0.0.8.tar.gz: lib/src/ui/common/bouncing_dots.dart <==
import 'package:flutter/material.dart';
import 'dart:math';

class BouncingDots extends StatefulWidget {
  const BouncingDots({Key? key}) : super(key: key);

  @override
  State<BouncingDots> createState() => _BouncingDotsState();
}

class _BouncingDotsState extends State<BouncingDots>
    with SingleTickerProviderStateMixin {
  late AnimationController _controller;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      duration: const Duration(seconds: 1),
      vsync: this,
    )..repeat(reverse: true);
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        AnimatedDot(animation: _controller, index: 0),
        AnimatedDot(animation: _controller, index: 1),
        AnimatedDot(animation: _controller, index: 2),
      ],
    );
  }
}

class AnimatedDot extends StatelessWidget {
  final AnimationController animation;
  final int index;

  const AnimatedDot({Key? key, required this.animation, required this.index})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animation,
      builder: (BuildContext context, Widget? child) {
        final double t = (animation.value - 0.2 * index).clamp(0.0, 1.0);
        final double yOffset = -4 * sin(pi * t);
        return Transform.translate(
          offset: Offset(0, yOffset),
          child: child,
        );
      },
      child: Container(
        width: 10,
        height: 10,
        margin: const EdgeInsets.all(5),
        decoration: const BoxDecoration(
          shape: BoxShape.circle,
          color: Colors.white,
        ),
      ),
    );
  }
}

==> flutterbudpay-0.0.9.tar.gz: lib/src/ui/common/bouncing_dots.dart <==
import 'package:flutter/material.dart';
import 'dart:math';

class BouncingDots extends StatefulWidget {
  final Color color;
  const BouncingDots({Key? key, this.color = Colors.white}) : super(key: key);

  @override
  State<BouncingDots> createState() => _BouncingDotsState();
}

class _BouncingDotsState extends State<BouncingDots>
    with SingleTickerProviderStateMixin {
  late AnimationController _controller;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      duration: const Duration(seconds: 1),
      vsync: this,
    )..repeat(reverse: true);
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        AnimatedDot(animation: _controller, index: 0, color: widget.color),
        AnimatedDot(animation: _controller, index: 1, color: widget.color),
        AnimatedDot(animation: _controller, index: 2, color: widget.color),
      ],
    );
  }
}

class AnimatedDot extends StatelessWidget {
  final AnimationController animation;
  final int index;
  final Color color;

  const AnimatedDot(
      {Key? key,
      required this.animation,
      required this.index,
      this.color = Colors.white})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animation,
      builder: (BuildContext context, Widget? child) {
        final double t = (animation.value - 0.2 * index).clamp(0.0, 1.0);
        final double yOffset = -4 * sin(pi * t);
        return Transform.translate(
          offset: Offset(0, yOffset),
          child: child,
        );
      },
      child: Container(
        width: 10,
        height: 10,
        margin: const EdgeInsets.all(5),
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          color: color,
        ),
      ),
    );
  }
}
